Enum allocator_api::AllocErr
[−]
[src]
pub enum AllocErr {
Exhausted {
request: Layout,
},
Unsupported {
details: &'static str,
},
}The AllocErr error specifies whether an allocation failure is
specifically due to resource exhaustion or if it is due to
something wrong when combining the given input arguments with this
allocator.
Variants
ExhaustedError due to hitting some resource limit or otherwise running out of memory. This condition strongly implies that some series of deallocations would allow a subsequent reissuing of the original allocation request to succeed.
Fields of Exhausted
request: Layout |
UnsupportedError due to allocator being fundamentally incapable of satisfying the original request. This condition implies that such an allocation request will never succeed on the given allocator, regardless of environment, memory pressure, or other contextual conditions.
For example, an allocator that does not support requests for large memory blocks might return this error variant.
Fields of Unsupported
details: &'static str |
Methods
impl AllocErr[src]
pub fn invalid_input(details: &'static str) -> Self[src]
pub fn is_memory_exhausted(&self) -> bool[src]
pub fn is_request_unsupported(&self) -> bool[src]
pub fn description(&self) -> &str[src]